@@ -1,10 +1,7 @@
 from azfs.clients.client_interface import ClientInterface
-from azure.storage.filedatalake import (
-    DataLakeFileClient,
-    FileSystemClient
-)
 from typing import Union
 from azure.identity import DefaultAzureCredential
+from azure.storage.filedatalake import DataLakeFileClient, FileSystemClient
 
 
 class AzDataLakeClient(ClientInterface):
@@ -41,7 +38,7 @@ class AzDataLakeClient(ClientInterface):
             [f.name for f in self.get_container_client_from_path(path=path).get_paths(path=file_path, recursive=True)]
         return file_list
 
-    def _get(self, path: str):
+    def _get(self, path: str, **kwargs):
         file_bytes = self.get_file_client_from_path(path).download_file().readall()
         return file_bytes
 
